# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: serpent_serve/serpent.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'serpent_serve/serpent.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bserpent_serve/serpent.proto\x12\x07serpent\"\x07\n\x05\x45mpty\"H\n\nArgsKwargs\x12\x11\n\x04\x61rgs\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06kwargs\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_argsB\t\n\x07_kwargs\"E\n\nMethodCall\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\'\n\nargsKwargs\x18\x02 \x01(\x0b\x32\x13.serpent.ArgsKwargs\"&\n\x06Result\x12\x12\n\x05value\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_value\"\x15\n\x05\x45rror\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"Z\n\x08Response\x12!\n\x06result\x18\x01 \x01(\x0b\x32\x0f.serpent.ResultH\x00\x12\x1f\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0e.serpent.ErrorH\x00\x42\n\n\x08response\"4\n\rSetupResponse\x12\x12\n\nattributes\x18\x01 \x03(\t\x12\x0f\n\x07methods\x18\x02 \x03(\t\"\x14\n\x04\x41ttr\x12\x0c\n\x04name\x18\x01 \x01(\t\"(\n\tAttrValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t2\xd1\x01\n\x07Serpent\x12\x31\n\x05Setup\x12\x0e.serpent.Empty\x1a\x16.serpent.SetupResponse\"\x00\x12\x30\n\x04\x43\x61ll\x12\x13.serpent.MethodCall\x1a\x11.serpent.Response\"\x00\x12-\n\x07GetAttr\x12\r.serpent.Attr\x1a\x11.serpent.Response\"\x00\x12\x32\n\x07SetAttr\x12\x12.serpent.AttrValue\x1a\x11.serpent.Response\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'serpent_serve.serpent_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EMPTY']._serialized_start=40
  _globals['_EMPTY']._serialized_end=47
  _globals['_ARGSKWARGS']._serialized_start=49
  _globals['_ARGSKWARGS']._serialized_end=121
  _globals['_METHODCALL']._serialized_start=123
  _globals['_METHODCALL']._serialized_end=192
  _globals['_RESULT']._serialized_start=194
  _globals['_RESULT']._serialized_end=232
  _globals['_ERROR']._serialized_start=234
  _globals['_ERROR']._serialized_end=255
  _globals['_RESPONSE']._serialized_start=257
  _globals['_RESPONSE']._serialized_end=347
  _globals['_SETUPRESPONSE']._serialized_start=349
  _globals['_SETUPRESPONSE']._serialized_end=401
  _globals['_ATTR']._serialized_start=403
  _globals['_ATTR']._serialized_end=423
  _globals['_ATTRVALUE']._serialized_start=425
  _globals['_ATTRVALUE']._serialized_end=465
  _globals['_SERPENT']._serialized_start=468
  _globals['_SERPENT']._serialized_end=677
# @@protoc_insertion_point(module_scope)
