# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from serpent_serve import serpent_pb2 as serpent__serve_dot_serpent__pb2

GRPC_GENERATED_VERSION = '1.68.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in serpent_serve/serpent_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SerpentStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Setup = channel.unary_unary(
                '/serpent.Serpent/Setup',
                request_serializer=serpent__serve_dot_serpent__pb2.Empty.SerializeToString,
                response_deserializer=serpent__serve_dot_serpent__pb2.SetupResponse.FromString,
                _registered_method=True)
        self.Call = channel.unary_unary(
                '/serpent.Serpent/Call',
                request_serializer=serpent__serve_dot_serpent__pb2.MethodCall.SerializeToString,
                response_deserializer=serpent__serve_dot_serpent__pb2.Response.FromString,
                _registered_method=True)
        self.GetAttr = channel.unary_unary(
                '/serpent.Serpent/GetAttr',
                request_serializer=serpent__serve_dot_serpent__pb2.Attr.SerializeToString,
                response_deserializer=serpent__serve_dot_serpent__pb2.Response.FromString,
                _registered_method=True)
        self.SetAttr = channel.unary_unary(
                '/serpent.Serpent/SetAttr',
                request_serializer=serpent__serve_dot_serpent__pb2.AttrValue.SerializeToString,
                response_deserializer=serpent__serve_dot_serpent__pb2.Response.FromString,
                _registered_method=True)


class SerpentServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Setup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Call(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAttr(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAttr(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SerpentServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Setup': grpc.unary_unary_rpc_method_handler(
                    servicer.Setup,
                    request_deserializer=serpent__serve_dot_serpent__pb2.Empty.FromString,
                    response_serializer=serpent__serve_dot_serpent__pb2.SetupResponse.SerializeToString,
            ),
            'Call': grpc.unary_unary_rpc_method_handler(
                    servicer.Call,
                    request_deserializer=serpent__serve_dot_serpent__pb2.MethodCall.FromString,
                    response_serializer=serpent__serve_dot_serpent__pb2.Response.SerializeToString,
            ),
            'GetAttr': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAttr,
                    request_deserializer=serpent__serve_dot_serpent__pb2.Attr.FromString,
                    response_serializer=serpent__serve_dot_serpent__pb2.Response.SerializeToString,
            ),
            'SetAttr': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAttr,
                    request_deserializer=serpent__serve_dot_serpent__pb2.AttrValue.FromString,
                    response_serializer=serpent__serve_dot_serpent__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'serpent.Serpent', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('serpent.Serpent', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Serpent(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Setup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/serpent.Serpent/Setup',
            serpent__serve_dot_serpent__pb2.Empty.SerializeToString,
            serpent__serve_dot_serpent__pb2.SetupResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Call(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/serpent.Serpent/Call',
            serpent__serve_dot_serpent__pb2.MethodCall.SerializeToString,
            serpent__serve_dot_serpent__pb2.Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAttr(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/serpent.Serpent/GetAttr',
            serpent__serve_dot_serpent__pb2.Attr.SerializeToString,
            serpent__serve_dot_serpent__pb2.Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetAttr(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/serpent.Serpent/SetAttr',
            serpent__serve_dot_serpent__pb2.AttrValue.SerializeToString,
            serpent__serve_dot_serpent__pb2.Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
